@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -37,21 +37,22 @@ typedef struct {
 
 /**
  * gsf_output_bonobo_new :
- * @stream : non-NULL bonobo stream
- * @err	     : optionally NULL.
+ * @stream : non-%NULL bonobo stream
+ * @err	   : optionally %NULL.
  *
- * Returns a new file or NULL.
+ * Returns: a new file or %NULL.
  **/
-GsfOutputBonobo *
-gsf_output_bonobo_new (Bonobo_Stream const stream, GError **err)
+GsfOutput *
+gsf_output_bonobo_new (Bonobo_Stream const stream, G_GNUC_UNUSED GError **err)
 {
-	GsfOutputBonobo *bonobo;
+	GsfOutputBonobo *res;
 
-	(void) err;
-	bonobo = g_object_new (GSF_OUTPUT_BONOBO_TYPE, NULL);
-	bonobo->stream = stream;
+	res = g_object_new (GSF_OUTPUT_BONOBO_TYPE, NULL);
+	if (G_UNLIKELY (NULL == res)) return NULL;
 
-	return bonobo;
+	res->stream = stream;
+
+	return GSF_OUTPUT (res);
 }
 
 static gboolean
@@ -119,7 +120,7 @@ gsf_output_bonobo_write (GsfOutput *output,
 	CORBA_exception_init (&ev);
 	Bonobo_Stream_write (bonobo->stream, bsobuf, &ev);
 	if (BONOBO_EX (&ev)) {
-		g_warning (bonobo_exception_get_text (&ev));
+		g_warning ("%s", bonobo_exception_get_text (&ev));
 		CORBA_exception_free (&ev);
 		return FALSE;
 	}
