@@ -73,7 +73,7 @@
  * mixture.
  */
 #define G_ARMFLOAT_ENDIAN 56781234
-#if defined(__arm__) && !defined(__vfp__) && (G_BYTE_ORDER == G_LITTLE_ENDIAN)
+#if defined(__arm__) && !defined(__ARM_EABI__) && (G_BYTE_ORDER == G_LITTLE_ENDIAN)
 #define G_FLOAT_BYTE_ORDER G_ARMFLOAT_ENDIAN
 #else
 #define G_FLOAT_BYTE_ORDER G_BYTE_ORDER
@@ -84,11 +84,6 @@
 static void base64_init (void);
 #endif
 
-#ifdef G_OS_WIN32
-#include <windows.h>
-G_WIN32_DLLMAIN_FOR_DLL_NAME (static, dll_name)
-#endif
-
 #ifdef _GSF_GTYPE_THREADING_FIXED
 typedef GTypeModule      GsfDummyTypeModule;
 typedef GTypeModuleClass GsfDummyTypeModuleClass;
@@ -110,6 +105,19 @@ static GSF_CLASS (GsfDummyTypeModule, gsf_dummy_type_module,
 static GTypeModule *static_type_module = NULL;
 #endif
 
+#ifdef G_OS_WIN32
+#include <windows.h>
+static HMODULE gsf_dll_hmodule;
+BOOL WINAPI
+DllMain (HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved);
+BOOL WINAPI
+DllMain (HINSTANCE hinstDLL, DWORD fdwReason, G_GNUC_UNUSED LPVOID lpvReserved)
+{
+	if (fdwReason == DLL_PROCESS_ATTACH) gsf_dll_hmodule = hinstDLL;
+	return TRUE;
+}
+#endif
+
 /**
  * gsf_init :
  *
@@ -118,18 +126,23 @@ static GTypeModule *static_type_module = NULL;
 void
 gsf_init (void)
 {
+	static gboolean libgsf_initialized = FALSE;
+	if (libgsf_initialized)
+		return;
+
 #ifdef ENABLE_NLS
 #ifdef G_OS_WIN32
-#undef GNOMELOCALEDIR
-	gchar *prefix = g_win32_get_package_installation_directory (NULL, dll_name);
-	gchar *GNOMELOCALEDIR = g_build_filename (prefix, "lib/locale", NULL);
-	g_free (prefix);
+	{
+		char *pkg_dir	  = g_win32_get_package_installation_directory_of_module (gsf_dll_hmodule);
+		gchar *locale_dir = g_build_filename (pkg_dir, "lib/locale", NULL);
+		bindtextdomain (GETTEXT_PACKAGE, locale_dir);
+		g_free (locale_dir);
+		g_free (pkg_dir);
+	}
+#else
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 #endif
-	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
-#ifdef G_OS_WIN32
-	g_free (GNOMELOCALEDIR);
-#endif
-	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
 
 	g_type_init ();
@@ -821,7 +834,7 @@ gsf_base64_encode_step (guint8 const *in, size_t len,
 
 
 /**
- * gsf_base64_decode_step: decode a chunk of base64 encoded data
+ * gsf_base64_decode_step:
  * @in: input stream
  * @len: max length of data to decode
  * @out: output stream
@@ -933,7 +946,7 @@ gsf_base64_decode_simple (guint8 *data, size_t len)
 
 /* Largely a copy of g_object_new_valist.  */
 /**
- * gsf_property_settings_collect_valist: collect property setting from a va_list.
+ * gsf_property_settings_collect_valist:
  * @object_type: the GType for which the properties are being set.
  * @p_n_params: a pointer to the number of properties collected.  (Used for
  *   both input and output.)
